<?php
/**
 * Giapeto base inclusion file.
 *
 * This file brings in all of the dependencies that every Giapeto script
 * will need, and sets up objects that all scripts use.
 *
 * $Horde: giapeto/lib/base.php,v 1.69 2007/01/02 12:47:38 jan Exp $
 *
 * Copyright 2002-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

// Check for a prior definition of HORDE_BASE (perhaps by an
// auto_prepend_file definition for site customization).
if (!defined('HORDE_BASE')) {
    @define('HORDE_BASE', dirname(__FILE__) . '/../..');
}

// Load the Horde Framework core, and set up inclusion paths.
require_once HORDE_BASE . '/lib/core.php';

/* Set up the registry. */
$registry = &Registry::singleton();
if (is_a(($pushed = $registry->pushApp('giapeto', !defined('AUTH_HANDLER'))), 'PEAR_Error')) {
    if ($pushed->getCode() == 'permission_denied') {
        Horde::authenticationFailureRedirect();
    }
    Horde::fatal($pushed, __FILE__, __LINE__, false);
}
$conf = &$GLOBALS['conf'];
@define('GIAPETO_TEMPLATES', $registry->get('templates'));

/* Horde Notification system. */
$notification = &Notification::singleton();
$notification->attach('status');

/* Find the base file path of Giapeto. */
@define('GIAPETO_BASE', dirname(__FILE__) . '/..');

/* Horde libraries. */
require_once 'Horde/Identity.php';
require_once 'Horde/Help.php';
require_once 'Horde/DataTree.php';

/* Start compression if configured. */
Horde::compressOutput();

/* Giapeto Permissions extend the Permissions class. */
require_once GIAPETO_BASE . '/lib/Perms.php';
$GLOBALS['giapeto_perms'] = &new Giapeto_Perms();

/* Horde Template class. */
require_once 'Horde/Template.php';

/* Giapeto base libraries. */
require_once GIAPETO_BASE . '/lib/Giapeto.php';

/* VFS. */
require_once 'VFS.php';
$GLOBALS['vfs'] = &VFS::singleton($conf['vfs']['type'],
                                  Horde::getDriverConfig('vfs',
                                                         $conf['vfs']['type']));

/* Enable bookmarks if required. */
if ($conf['site']['bookmarks']) {
    require_once GIAPETO_BASE . '/lib/Bookmarks.php';
    $bookmarks = &Giapeto_Bookmarks::singleton('sql', Horde::getDriverConfig('sql'));
    $bookmarks->initialise();
}

/* Enable stats if required. */
if ($conf['site']['stats']) {
    require_once GIAPETO_BASE . '/lib/Stats.php';
    $stats = &Giapeto_Stats::singleton('sql', Horde::getDriverConfig('sql'));
    $stats->initialise();
}

/* Get identity. */
$identity = &Identity::singleton();
$fullname = $identity->getValue('fullname');
if (empty($fullname)) {
    $fullname = Auth::getAuth();
}
