<?php
/**
 * The Giapeto script to show permissions for a page.
 *
 * $Horde: giapeto/perms/index.php,v 1.15 2007/01/02 12:47:41 jan Exp $
 *
 * Copyright 2004-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Marko Djukic <marko@oblo.com>
 */

@define('GIAPETO_BASE', dirname(__FILE__) . '/..');
require_once GIAPETO_BASE . '/lib/base.php';

/* Set up the giapeto class */
$giapeto = &Giapeto::singleton();

$page_id = Util::getFormData('page_id');

$page = &$giapeto->getPage($page_id);
if (is_a($page, 'PEAR_Error')) {
    /* Try the root page. */
    $page_id = $giapeto->getUrlCategoryId('__root');
    $page = &$giapeto->getPage($page_id);
    if (is_a($page, 'PEAR_Error')) {
        /* Definately give up here. */
        Horde::fatal($page, __FILE__, __LINE__);
    }
}

/* Check if user authorised for this. */
if (!$giapeto_perms->checkPermissions($page_id, 'page', PERMS_EDIT)) {
    $notification->push(_("You are not authorized."), 'horde.error');
    $url = $giapeto->getIdUrl($page_id, 1);
    header('Location: ' . $url);
    exit;
}

$base_perms = array();
$user_perms = array();
$group_perms = array();
$perm_name = 'giapeto:pages:' . $page_id;
$permission = &$perms->getPermission($perm_name);
if (!is_a($permission, 'PEAR_Error')) {
    $tick = Horde::img('tick.png', _("enabled"));
    $cross = Horde::img('cross.png', _("disabled"));
    $perm_val = $permission->getDefaultPermissions();
    $base_perms[] = array('name' => _("default"),
                          'show' => ($perm_val & PERMS_SHOW) ? $tick : $cross,
                          'read' => ($perm_val & PERMS_READ) ? $tick : $cross,
                          'edit' => ($perm_val & PERMS_EDIT) ? $tick : $cross,
                          'delete' => ($perm_val & PERMS_DELETE) ? $tick : $cross);

    $perm_val = $permission->getGuestPermissions();
    $base_perms[] = array('name' => _("guest"),
                          'show' => ($perm_val & PERMS_SHOW) ? $tick : $cross,
                          'read' => ($perm_val & PERMS_READ) ? $tick : $cross,
                          'edit' => ($perm_val & PERMS_EDIT) ? $tick : $cross,
                          'delete' => ($perm_val & PERMS_DELETE) ? $tick : $cross);

    $perm_val = $permission->getUserPermissions();
    foreach ($perm_val as $user => $val) {
        $user_perms[] = array('name' => $user,
                              'show' => ($val & PERMS_SHOW) ? $tick : $cross,
                              'read' => ($val & PERMS_READ) ? $tick : $cross,
                              'edit' => ($val & PERMS_EDIT) ? $tick : $cross,
                              'delete' => ($val & PERMS_DELETE) ? $tick : $cross);
    }

    $perm_val = $permission->getGroupPermissions();
    require_once 'Horde/Group.php';
    $groups = &Group::singleton();
    foreach ($perm_val as $group => $val) {
        $group_perms[] = array('name' => $groups->getGroupName($group),
                               'show' => ($val & PERMS_SHOW) ? $tick : $cross,
                               'read' => ($val & PERMS_READ) ? $tick : $cross,
                               'edit' => ($val & PERMS_EDIT) ? $tick : $cross,
                               'delete' => ($val & PERMS_DELETE) ? $tick : $cross);
    }
}

/* Set up template tags. */
$template = &new Horde_Template();
$template->set('menu', Giapeto::getMenu('string'));
$template->set('tree', $giapeto->renderPermsTree($page_id, $page_id));
$template->set('base_perms', $base_perms);
$template->set('user_perms', $user_perms, true);
$template->set('group_perms', $group_perms, true);

/* Set notification tag. */
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/perms/index.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
